@@ -6,21 +6,21 @@ doRhpkgContainerBuild=1
 forceBuild=0
 forcePull=0
 while [[ "$#" -gt 0 ]]; do
-  case $1 in
-    '-n'|'--nobuild') doRhpkgContainerBuild=0; shift 0;;
-    '-f'|'--force-build') forceBuild=1; shift 0;;
-    '-p'|'--force-pull') forcePull=1; shift 0;;
-    '-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
-    *) JOB_BRANCH="$1"; shift 0;;
-  esac
-  shift 1
+	case $1 in
+		'-n'|'--nobuild') doRhpkgContainerBuild=0; shift 0;;
+		'-f'|'--force-build') forceBuild=1; shift 0;;
+		'-p'|'--force-pull') forcePull=1; shift 0;;
+		'-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
+		*) JOB_BRANCH="$1"; shift 0;;
+	esac
+	shift 1
 done
 
 function log()
 {
-  if [[ ${verbose} -gt 0 ]]; then
-    echo "$1"
-  fi
+	if [[ ${verbose} -gt 0 ]]; then
+		echo "$1"
+	fi
 }
 
 # if not set, compute from current branch
@@ -67,52 +67,52 @@ jenkinsURL=${jenkinsURL}/lastSuccessfulBuild/artifact/codeready-workspaces-depre
 
 # patch Dockerfile to record versions we expect
 sed Dockerfile \
-    -e "s#KAMEL_VERSION=\"\([^\"]\+\)\"#KAMEL_VERSION=\"${KAMEL_VERSION}\"#" \
-    > Dockerfile.2
+		-e "s#KAMEL_VERSION=\"\([^\"]\+\)\"#KAMEL_VERSION=\"${KAMEL_VERSION}\"#" \
+		> Dockerfile.2
 
 if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile Dockerfile.2) ]] || [[ ${forcePull} -eq 1 ]]; then
-  rm -fr asset-*
-  mv -f Dockerfile.2 Dockerfile
-  # x86
-  curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-x86_64.tar.gz | tar -xz && mv kamel asset-x86_64-kamel
+	rm -fr asset-*
+	mv -f Dockerfile.2 Dockerfile
+	# x86
+	curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-x86_64.tar.gz | tar -xz && mv kamel asset-x86_64-kamel
 
-  # s390x
-  curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-s390x.tar.gz | tar -xz && mv kamel asset-s390x-kamel
+	# s390x
+	curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-s390x.tar.gz | tar -xz && mv kamel asset-s390x-kamel
 
-  # ppc64le
-  curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-ppc64le.tar.gz | tar -xz && mv kamel asset-ppc64le-kamel
-  
-  for d in asset-*; do echo "[INFO] Pack ${d}.tar.gz"; mv ${d} ${d##*-}; tar -cvzf ${d}.tar.gz ${d##*-}; mv ${d##*-} ${d}-unpacked; done
-  rm -fr asset-*-unpacked
+	# ppc64le
+	curl -sSLo - ${jenkinsURL}/kamel-${KAMEL_VERSION}-ppc64le.tar.gz | tar -xz && mv kamel asset-ppc64le-kamel
+	
+	for d in asset-*; do echo "[INFO] Pack ${d}.tar.gz"; mv ${d} ${d##*-}; tar -cvzf ${d}.tar.gz ${d##*-}; mv ${d##*-} ${d}-unpacked; done
+	rm -fr asset-*-unpacked
 fi
 
 # rhpkg sources
 outputFiles="$(ls asset-*.tar.gz || true)"
 if [[ ${outputFiles} ]]; then
-  log "[INFO] Upload new sources: ${outputFiles}"
-  rhpkg new-sources ${outputFiles}
-  log "[INFO] Commit new sources from: ${outputFiles}"
+	log "[INFO] Upload new sources: ${outputFiles}"
+	rhpkg new-sources ${outputFiles}
+	log "[INFO] Commit new sources from: ${outputFiles}"
 	field=id; ID=$(curl -L -s -S ${lastSuccessfulURL}${field} | sed -e "s#<${field}>\(.\+\)</${field}>#\1#" -e "s#&lt;br/&gt; #\n#g" -e "s#\&lt;a.\+/a\&gt;##g")
 	if [[ $(echo $ID | grep -E "404 Not Found|ERROR 404|Application is not available") ]]; then 
 		echo $ID
 		echo "[ERROR] Problem loading ID from ${lastSuccessfulURL}${field} :: NOT FOUND!"
 		exit 1;
 	fi
-  COMMIT_MSG="Update from Jenkins :: kamel ${KAMEL_VERSION} from ${UPSTREAM_JOB_NAME} :: ${ID}
+	COMMIT_MSG="Update from Jenkins :: kamel ${KAMEL_VERSION} from ${UPSTREAM_JOB_NAME} :: ${ID}
 :: ${outputFiles}"
 	if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile .gitignore) == *"nothing to commit, working tree clean"* ]] ;then 
 		log "[INFO] No new sources, so nothing to build."
 	elif [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
 		log "[INFO] Push change:"
-		git pull; git push
+		git pull; git push; git status -s || true
 	fi
 	if [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
-    echo "[INFO] #1 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-	git status || true
-    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
-    taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
-    if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
+		echo "[INFO] #1 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
+		git status || true
+		tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+		taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
+		ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
+		if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
 
@@ -120,12 +120,12 @@ $ERRORS
 	fi
 else
 	if [[ ${forceBuild} -eq 1 ]]; then
-    echo "[INFO] #2 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-	git status || true
-    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
-    taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
-    if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
+		echo "[INFO] #2 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
+		git status || true
+		tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+		taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
+		ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
+		if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
 
